@@ -28,9 +28,37 @@
 #endif
 
 #include <qwidget.h>
+#include <qstring.h>
 #include <qlabel.h>
 
+#include <kfiledialog.h>
+#include <kurl.h>
+#include <kconfig.h>
+#include <kaction.h>
 #include <kdialog.h>
+#include <kpushbutton.h>
+#include <kio/job.h>
+#include <kio/jobclasses.h>
+#include <kprocess.h>
+
+
+class AppendFileDlg: public KFileDialog
+{
+	Q_OBJECT
+public:
+	AppendFileDlg(const QString &startDir, const QString &filter, QWidget *parent, const char *name, bool modal);
+	~AppendFileDlg();
+
+	static KURL getOpenURL(const QString &startDir = QString::null, QWidget *parent = 0);
+
+public slots:
+	void slotGoCt();
+	void slotGoIx();
+
+private:
+	KConfig *config;
+	KAction *goCt, *goIx;
+};
 
 
 class AppendDlg: public KDialog
@@ -40,18 +68,27 @@ public:
 	AppendDlg(QWidget *parent = 0, const char *name = 0);
 	virtual ~AppendDlg();
 
+	bool appendFile(const QString &filename);
+
 private slots:
 	void slotHelp();
 	void slotAppend();
+
+	void slotCopyResult(KIO::Job *job);
+	void slotUnzipExited(KProcess *proc);
 	
 private:
 	void scanEntries();
+	void purgeDir();
 
-	QLabel *ct_first, *ct_last, *ct_article_no;
-	QLabel *ix_first, *ix_last, *ix_article_no;
+	QString m_filename;
+	KIO::FileCopyJob *m_copyjob;
+	KProcess *m_unzipproc;
 
-	int ct_first_ed, ct_last_ed, ct_articles;
-	int ix_first_ed, ix_last_ed, ix_articles;
+	QLabel *ct_first, *ct_last, *ct_editions, *ct_articles;
+	QLabel *ix_first, *ix_last, *ix_editions, *ix_articles;
+
+	KPushButton *bappend;
 };
 
 
