@@ -54,6 +54,8 @@ protected slots:
 
 private slots:
 	void slotFuzzyToggled(bool on);
+	void slotBrowseMountPt();
+	void slotExternalToggled(bool on);
 
 private:
 	KConfig *config;
@@ -66,6 +68,9 @@ private:
 	QSlider *sea_threshold;
 
 	QLineEdit *net_cturl, *net_ixurl;
+
+	QLineEdit *ctrom_mountpt, *ctrom_browsercom;
+	QCheckBox *ctrom_extbrowser;
 };
 
 
