@@ -33,6 +33,7 @@
 #include <kmainwindow.h>
 #include <kconfig.h>
 #include <kaction.h>
+#include <kprocess.h>
 
 #include "kheiseview.h"
 #include "searchdlg.h"
@@ -59,13 +60,17 @@ public slots:
 	void slotFileOpen();
 	void slotFileQuit();
 	
-	void slotSearchSearch();
+	void slotArticleSearch();
+	void slotArticleView();
+	void slotArticlePrint();
 
 	void slotSettingsShowToolbar();
 	void slotSettingsShowStatusbar();
 	void slotSettingsSaveOptions();
 	void slotSettingsConfigure();
-		
+
+	void slotHasSelection(bool ct);
+
 	void slotStatusMsg(const QString &text);
 	void slotStatusHelpMsg(const QString &text);
 	void slotStatusItems(int items);
@@ -77,12 +82,14 @@ private:
 	KConfig *config;
 
 	KAction *fileOpen, *fileQuit;
-	KAction *searchSearch;
+	KAction *articleSearch, *articleView, *articlePrint;
 	KToggleAction *settingsShowToolbar, *settingsShowStatusbar;
 	KAction *settingsSaveOptions, *settingsConfigure;
 
 	KHeiseView *view;
 	SearchDlg *searchdlg;
+
+	KShellProcess proc;
 };
 
 
