@@ -28,9 +28,12 @@
 #endif
 
 #include <qwidget.h>
+#include <qstring.h>
 #include <qlabel.h>
 #include <qlistview.h>
 
+#include <kaction.h>
+
 #include "articleview.h"
 
 
@@ -46,16 +49,47 @@ public:
 
 	void search(const RegMask &mask);
 
+	int articleYear();
+	int articleEdition();
+	int articlePage();
+
+	void plugContextMenu(KAction *action);
+
+	KListView *articleList();
+
 private slots:
 	void currentChangedSlot(QListViewItem *item);
 
 signals:
 	void items(int);
+	void hasSelection(bool);
 
 private:
 	ArticleView *articleview;
 	QLabel *title, *subtitle, *author, *editor, *magazine, *edition, *page, *links;
+
+	int cur_edition, cur_year, cur_page;
 };
 
 
+inline int KHeiseView::articleYear()
+{	return cur_year % 100; }
+
+
+inline int KHeiseView::articleEdition()
+{	return cur_edition; }
+
+
+inline int KHeiseView::articlePage()
+{	return cur_page; }
+
+
+inline void KHeiseView::plugContextMenu(KAction *action)
+{	articleview->plugContextMenu(action); }
+
+
+inline KListView *KHeiseView::articleList()
+{	return articleview; }
+
+
 #endif // KHEISEVIEW_H
